@@ -22,7 +22,8 @@ import subprocess
 import sys
 import tempfile
 import time
-from typing import Generator
+import typing
+from typing import Generator, List, Optional
 
 
 import pytest
@@ -37,7 +38,7 @@ def get_provider() -> str:
     """
     Return the provider to use for testing and allow to set it
     with PYTHON_VAGRANT_TEST_PROVIDER environment variable is set.
-    Defauts to virtualbox
+    Defaults to virtualbox.
     """
     my_prov = "virtualbox"
     if "PYTHON_VAGRANT_TEST_PROVIDER" in os.environ:
@@ -46,7 +47,7 @@ def get_provider() -> str:
 
 
 # location of Vagrant executable
-VAGRANT_EXE = vagrant.get_vagrant_executable()
+VAGRANT_EXE = typing.cast(str, vagrant.get_vagrant_executable())
 
 # location of a test file on the created box by provisioning in vm_Vagrantfile
 TEST_FILE_PATH = "/home/vagrant/python_vagrant_test_file"
@@ -106,7 +107,7 @@ def fixture_test_dir() -> Generator[str, None, None]:
         shutil.rmtree(my_dir)
 
 
-def list_box_names():
+def list_box_names() -> List[str]:
     """
     Return a list of the currently installed vagrant box names.  This is
     implemented outside of `vagrant.Vagrant`, so that it will still work
@@ -222,6 +223,54 @@ def test_parse_status(vm_dir):
     )
 
 
+def test_parse_global_status(vm_dir):
+    """
+    Test the parsing the output of the `vagrant global-status` command.
+    """
+    listing = """1651503808,,metadata,machine-count,2
+1651503808,,machine-id,9ec0e5d
+1651503808,,provider-name,libvirt
+1651503808,,machine-home,/tmp
+1651503808,,state,preparing
+1651503808,,machine-id,61395ad
+1651503808,,provider-name,libvirt
+1651503808,,machine-home,/home/rtp/.cache/molecule/sbd/default
+1651503808,,state,running
+1651504022,,ui,info,id
+1651504022,,ui,info,name
+1651504022,,ui,info,provider
+1651504022,,ui,info,state
+1651504022,,ui,info,directory
+1651504022,,ui,info,
+1651504022,,ui,info,-------------------------------------------------------------------------------------------------------------
+1651504022,,ui,info,9ec0e5d
+1651504022,,ui,info,bionic
+1651504022,,ui,info,libvirt
+1651504022,,ui,info,preparing
+1651504022,,ui,info,/tmp
+1651504022,,ui,info,
+1651504022,,ui,info,61395ad
+1651504022,,ui,info,instance-sbd-default
+1651504022,,ui,info,libvirt
+1651504022,,ui,info,running
+1651504022,,ui,info,/home/rtp/.cache/molecule/sbd/default
+1651504022,,ui,info,
+11651504022,,ui,info, \\nThe above shows information about all known Vagrant environments\\non this machine...
+"""
+    # Can compare tuples to GlobalStatus class b/c GlobalStatus is a collections.namedtuple.
+    goal = [
+        ("9ec0e5d", "preparing", "libvirt", "/tmp"),
+        ("61395ad", "running", "libvirt", "/home/rtp/.cache/molecule/sbd/default"),
+    ]
+    v = vagrant.Vagrant(vm_dir)
+    parsed = v._parse_global_status(listing)
+    assert (
+        goal == parsed
+    ), "The parsing of the test listing did not match the goal.\nlisting={!r}\ngoal={!r}\nparsed_listing={!r}".format(
+        listing, goal, parsed
+    )
+
+
 def test_parse_aws_status(vm_dir):
     """
     Test the parsing the output of the `vagrant status` command for an aws instance.
@@ -666,7 +715,7 @@ def test_streaming_output(vm_dir):
         v.up(vm_name="incorrect-name")
 
     streaming_up = False
-    for line in v.up(stream_output=True):
+    for line in v.up(stream_output=True):  # type: ignore
         print("output line:", line)
         if test_string in line:
             streaming_up = True
@@ -674,7 +723,7 @@ def test_streaming_output(vm_dir):
     assert streaming_up
 
     streaming_reload = False
-    for line in v.reload(stream_output=True):
+    for line in v.reload(stream_output=True):  # type: ignore
         print("output line:", line)
         if test_string in line:
             streaming_reload = True
@@ -711,7 +760,7 @@ def test_vagrant_version():
     assert version_result is True
 
 
-def _execute_command_in_vm(v, command):
+def _execute_command_in_vm(v, command) -> str:
     """
     Run command via ssh on the test vagrant box.  Returns a tuple of the
     return code and output of the command.
@@ -721,7 +770,7 @@ def _execute_command_in_vm(v, command):
     return compat.decode(subprocess.check_output(ssh_command, cwd=v.root))
 
 
-def _write_test_file(v, file_contents):
+def _write_test_file(v, file_contents) -> None:
     """
     Writes given contents to the test file.
     """
@@ -729,7 +778,7 @@ def _write_test_file(v, file_contents):
     _execute_command_in_vm(v, command)
 
 
-def _read_test_file(v):
+def _read_test_file(v) -> Optional[str]:
     """
     Returns the contents of the test file stored in the VM or None if there
     is no file.
@@ -742,6 +791,6 @@ def _read_test_file(v):
         return None
 
 
-def _plugin_installed(v, plugin_name):
+def _plugin_installed(v, plugin_name) -> bool:
     plugins = v.plugin_list()
     return plugin_name in [plugin.name for plugin in plugins]
